@@ -202,7 +202,11 @@ class ContactMechanism(
 
     @classmethod
     def search_rec_name(cls, name, clause):
-        return ['OR',
+        if clause[1].startswith('!') or clause[1].startswith('not '):
+            bool_op = 'AND'
+        else:
+            bool_op = 'OR'
+        return [bool_op,
             ('value',) + tuple(clause[1:]),
             ('value_compact',) + tuple(clause[1:]),
             ]
